// (c) Thomas Kamps, 2009
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include "monopgroup.h"

MonopGroup::MonopGroup(int id, QString n) {
	gid = id;
	name = n;
}

int MonopGroup::getId() {
	return gid;
}

QString MonopGroup::getName() {
	return name;
}

int MonopGroup::getNumEstates() {
	return estates.size();
}

MonopdField* MonopGroup::getEstate(int i) {
	if (i < 0) return 0;
	if (i >= getNumEstates()) return 0;

	return estates.value(i);
}

void MonopGroup::addEstate(MonopdField* f) {
	estates.append(f);
}

bool MonopGroup::getAllEstatesSameOwner() {
	if (estates.size() == 0) return false;
	int owner = estates.value(0)->getOwner();
	if (owner == -1) return false;

	foreach (MonopdField* f, estates) {
		if (owner != f->getOwner()) return false;
	}

	return true;
}

int MonopGroup::getNumHouses() {
	int n = 0;

	foreach (MonopdField* f, estates) {
		n += f->getHouses();
	}

	return n;
}

bool MonopGroup::canBuyHouseRow() {
	bool canBuyRow = true;
	foreach (MonopdField* f, estates) {
		canBuyRow = canBuyRow && f->getCanBuyHouse();
	}
	return canBuyRow;
}

bool MonopGroup::canSellHouseRow() {
	bool canSellRow = true;
	foreach (MonopdField* f, estates) {
		canSellRow = canSellRow && f->getCanSellHouse();
	}
	return canSellRow;
}

